@@ -2301,9 +2301,9 @@ start_glib_signal (GMarkupParseContext *context,
   signal->run_first = FALSE;
   signal->run_last = FALSE;
   signal->run_cleanup = FALSE;
-  if (when == NULL || strcmp (when, "LAST") == 0)
+  if (when == NULL || g_ascii_strcasecmp (when, "LAST") == 0)
     signal->run_last = TRUE;
-  else if (strcmp (when, "FIRST") == 0)
+  else if (g_ascii_strcasecmp (when, "FIRST") == 0)
     signal->run_first = TRUE;
   else
     signal->run_cleanup = TRUE;
@@ -2748,7 +2748,8 @@ start_element_handler (GMarkupParseContext *context,
 			       attribute_names, attribute_values,
 			       ctx, error))
 	goto out;
-      if (strcmp (element_name, "doc") == 0)
+      if (strcmp ("doc", element_name) == 0 || strcmp ("doc-deprecated", element_name) == 0 ||
+          strcmp ("doc-stability", element_name) == 0 || strcmp ("doc-version", element_name) == 0)
         {
           state_switch (ctx, STATE_PASSTHROUGH);
           goto out;
