@@ -69,9 +69,6 @@ class GIRParser(object):
     def get_namespace(self):
         return self._namespace
 
-    def get_c_prefix(self):
-        return self._c_prefix
-
     # Private
 
     def _find_first_child(self, node, name_or_names):
@@ -180,12 +177,24 @@ class GIRParser(object):
         version = node.attrib.get('version')
         if version:
             obj.version = version
-        deprecated = node.attrib.get('deprecated')
+        version_doc = node.find(_corens('doc-version'))
+        if version_doc is not None:
+            if version_doc.text:
+                obj.version_doc = version_doc.text
+        deprecated = node.attrib.get('deprecated-version')
         if deprecated:
             obj.deprecated = deprecated
-        deprecated_version = node.attrib.get('deprecated-version')
-        if deprecated_version:
-            obj.deprecated_version = deprecated_version
+        deprecated_doc = node.find(_corens('doc-deprecated'))
+        if deprecated_doc is not None:
+            if deprecated_doc.text:
+                obj.deprecated_doc = deprecated_doc.text
+        stability = node.attrib.get('stability')
+        if stability:
+            obj.stability = stability
+        stability_doc = node.find(_corens('doc-stability'))
+        if stability_doc is not None:
+            if stability_doc.text:
+                obj.stability_doc = stability_doc.text
 
     def _parse_object_interface(self, node):
         parent = node.attrib.get('parent')
@@ -322,7 +331,7 @@ class GIRParser(object):
             for i, paramnode in enumerate(self._find_children(parameters_node,
                                                               _corens('parameter'))):
                 param = parameters[i]
-                self._parse_type_second_pass(func, paramnode, param.type)
+                self._parse_type_array_length(parameters, paramnode, param.type)
                 closure = paramnode.attrib.get('closure')
                 if closure:
                     idx = int(closure)
@@ -334,7 +343,7 @@ class GIRParser(object):
                     assert idx < len(parameters), "%d >= %d" % (idx, len(parameters))
                     param.destroy_name = parameters[idx].argname
 
-        self._parse_type_second_pass(func, returnnode, retval.type)
+        self._parse_type_array_length(parameters, returnnode, retval.type)
 
         self._parse_generic_attribs(node, func)
 
@@ -366,6 +375,9 @@ class GIRParser(object):
                 func = self._parse_function_common(method, ast.Function, compound)
                 func.is_method = True
                 compound.methods.append(func)
+            for i, fieldnode in enumerate(self._find_children(node, _corens('field'))):
+                field = compound.fields[i]
+                self._parse_type_array_length(compound.fields, fieldnode, field.type)
             for func in self._find_children(node, _corens('function')):
                 compound.static_methods.append(
                     self._parse_function_common(func, ast.Function, compound))
@@ -447,8 +459,8 @@ class GIRParser(object):
                 return self._parse_type_simple(typenode)
         assert False, "Failed to parse toplevel type"
 
-    def _parse_type_second_pass(self, parent, node, typeval):
-        """A hack necessary to handle the integer parameter indexes on
+    def _parse_type_array_length(self, siblings, node, typeval):
+        """A hack necessary to handle the integer parameter/field indexes on
            array types."""
         typenode = node.find(_corens('array'))
         if typenode is None:
@@ -456,9 +468,11 @@ class GIRParser(object):
         lenidx = typenode.attrib.get('length')
         if lenidx is not None:
             idx = int(lenidx)
-            assert idx < len(parent.parameters), "%r %d >= %d" % (parent, idx,
-                                                                  len(parent.parameters))
-            typeval.length_param_name = parent.parameters[idx].argname
+            assert idx < len(siblings), "%r %d >= %d" % (parent, idx, len(siblings))
+            if isinstance(siblings[idx], ast.Field):
+                typeval.length_param_name = siblings[idx].name
+            else:
+                typeval.length_param_name = siblings[idx].argname
 
     def _parse_boxed(self, node):
         obj = ast.Boxed(node.attrib[_glibns('name')],
